package Bencher::Scenarios::AppLcpan;

our $DATE = '2016-01-06'; # DATE
our $VERSION = '0.03'; # VERSION

1;
# ABSTRACT: A collection of scenarios to benchmark App::lcpan

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Scenarios::AppLcpan - A collection of scenarios to benchmark App::lcpan

=head1 VERSION

This document describes version 0.03 of Bencher::Scenarios::AppLcpan (from Perl distribution Bencher-Scenarios-AppLcpan), released on 2016-01-06.

=head1 SEE ALSO

L<App::lcpan>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-AppLcpan>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-AppLcpan>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-AppLcpan>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
